@@ -612,8 +612,6 @@ static void S_parse_sigelem(pTHX_ struct SignatureParsingContext *ctx, U32 flags
         yyerror("Slurpy parameters not last");
 
       parser->sig_elems++;
-      ctx->positional_elems = op_append_list(OP_LINESEQ, ctx->positional_elems,
-          newSTATEOP(0, NULL, paramctx.varop));
     }
 
     bool default_if_undef = false, default_if_false = false;
@@ -680,6 +678,14 @@ static void S_parse_sigelem(pTHX_ struct SignatureParsingContext *ctx, U32 flags
       if(parser->sig_optelems)
         yyerror("Mandatory parameter follows optional parameter");
     }
+
+    if(!paramctx.is_named)
+      /* This call to newSTATEOP() must come AFTER parsing the defaulting
+       * expression because it involves an implicit intro_my() and so we must
+       * not introduce the new parameter variable beforehand (RT155630)
+       */
+      ctx->positional_elems = op_append_list(OP_LINESEQ, ctx->positional_elems,
+          newSTATEOP(0, NULL, paramctx.varop));
   }
   else {
     if(paramctx.is_named)
